@@ -35,22 +35,52 @@
 #' @references
 #' William G. Sullivan, Elin M. Wicks, and C. Patrick Koelling, \emph{Engineering Economy}, Fourteenth Edition, Upper Saddle River, New Jersey: Pearson/Prentice Hall, 2009, page 156-159.
 #'
+#'
+#'
+#'
+#' @author Irucka Embry
+#'
+#'
+#'
 #' @encoding UTF-8
 #'
 #'
+#'
+#'
+#'
+#'
+#'
 #' @examples
+#' 
 #' library("iemisc")
+#'
 #' # Example 4-23 from the Reference text (page 158-159)
-#' PgivenA1(1000, 25, 20, 4) # i is 25% and f is 20%
+#' PgivenA1(A1 = 1000, i = 25, f = 20, n = 4) # i is 25\% and f is 20\%
 #'
 #'
 #' # Example 4-24 from the Reference text (page 159)
-#' PgivenA1(1000, 25, -20, 4) # i is 25% and f is -20%
+#' PgivenA1(A1 = 1000, i = 25, f = -20, n = 4) # i is 25\% and f is -20\%
+#'
+#'
+#' @importFrom assertthat assert_that
+#' @importFrom checkmate qtest
+#' @importFrom round round_r3
 #'
 #'
 #' @export
 PgivenA1 <- function (A1, i, f, n) {
 
+
+checks <- c(A1, i, n)
+
+# check on A1, i, f, and n
+assert_that(!any(qtest(checks, "N+(0,)") == FALSE), msg = "Either A1, f, or n is 0 or less, NA, NaN, Inf, -Inf, empty, or a string. Please try again.")
+# only process with finite values and provide an error message if the check fails
+
+assert_that(!any(qtest(f, "N(,)") == FALSE), msg = "Either i is NA, NaN, Inf, -Inf, empty, or a string. Please try again.")
+# only process with finite values and provide an error message if the check fails
+
+
 i <- i / 100
 
 f <- f / 100
@@ -65,5 +95,5 @@ else {
 PgivenA1 <- A1 * n * (1 + i) ^ -1
 }
 
-return(round(PgivenA1, digits = 2))
+return(round_r3(PgivenA1, d = 2))
 }
